@@ -1674,6 +1674,26 @@ def _test_lineendings():
     """
 
 
+def _test_validate_with_copy_and_many():
+    """
+    >>> spec = '''
+    ... [section]
+    ... [[__many__]]
+    ... value = string(default='nothing')
+    ... '''
+    >>> config = '''
+    ... [section]
+    ... [[something]]
+    ... '''
+    >>> c = ConfigObj(StringIO(config), configspec=StringIO(spec))
+    >>> v = Validator()
+    >>> r = c.validate(v, copy=True)
+    >>> c['section']['something']['value']
+    'nothing'
+    """
+    
+    
+
 # TODO: Test BOM handling
 # TODO: Test error code for badly built multiline values
 # TODO: Test handling of StringIO
